.. _httpclient

==================
HTTP
==================

The :mod:`pulsar.utils.httpurl` contains several utilities useful when working
with synchronous and asynchronous HTTP connections.

.. automodule:: pulsar.utils.httpurl


API
================

HTTP Client
~~~~~~~~~~~~~~~~~~

.. autoclass:: HttpClient
   :members:
   :member-order: bysource
   
HTTP Request
~~~~~~~~~~~~~~~~~~

.. autoclass:: HttpRequest
   :members:
   :member-order: bysource
   
HTTP Response
~~~~~~~~~~~~~~~~~~

.. autoclass:: HttpResponse
   :members:
   :member-order: bysource
   
HTTP Parser
~~~~~~~~~~~~~~~~~

.. autoclass:: HttpParser
   :members:
   :member-order: bysource

Headers
~~~~~~~~~~~~~~

.. autoclass:: Headers
   :members:
   :member-order: bysource
   
Utilities
~~~~~~~~~~~~~~~~~

.. autofunction:: iri_to_uri

.. autofunction:: has_empty_content

